// LogEntry.h -- Declaration file for the LogEntry class
//               The LogEntry class describes an http log file entry
// Written by Dr. Chris Taylor, t a y l o r@m s o e.edu
// Date: 2-15-2003
// Modified 3-11-2003, t a y l o r@m s o e.edu: Added getStatus()

#ifndef LOGENTRY_H
#define LOGENTRY_H

#include <iostream>
#include <string>

class LogEntry {
public:
  // Constructor/Copy Constructor/Destructor/Assignment operator
  LogEntry();
  LogEntry(const LogEntry& org);
  ~LogEntry();
  LogEntry& operator=(const LogEntry& rhs);

  // Parse a log entry from a string
  bool extract(const std::string& entry);
  // Place a log entry back into the output stream
  void insert(std::ostream& os) const;
  // returns the hostIP or hostname (if logfile contains it)
  std::string getHost() const;
  // returns the RFC 1413 identity or - if not available
  std::string getIdentity() const;
  // returns the userid or - if not available
  std::string getUserid() const;
  // returns the day of the month or LogEntry::invalid if not available
  unsigned int getDay() const;
  // returns the month of the year or - if not available
  std::string getMonth() const;
  // returns the year or LogEntry::invalid if not available
  unsigned int getYear() const;
  // returns the hour or LogEntry::invalid if not available
  unsigned int getHour() const;
  // returns the minute or LogEntry::invalid if not available
  unsigned int getMinute() const;
  // returns the second or LogEntry::invalid if not available
  unsigned int getSecond() const;
  // returns the size of the requested file or LogEntry::invalid if not available
  unsigned int getSize() const;
  // returns the userid or - if not available
  std::string getReferrer() const;
  // returns the userid or - if not available
  std::string getUserAgent() const;
  // returns the status of the request or LogEntry::invalid if not available
  unsigned int getStatus() const;
  // Stores defined constant to indicate invalid value
  static const unsigned int invalid;
private:
  std::string host;
  std::string identity;
  std::string userid;
  unsigned int day;
  std::string month;
  unsigned int year;
  unsigned int hour;
  unsigned int minute;
  unsigned int second;
  std::string offset;
  std::string clientRequest;
  unsigned int status;
  unsigned int size;
  std::string referrer;
  std::string userAgent;
};

std::ostream& operator<<(std::ostream& os, const LogEntry& entry);
std::istream& operator>>(std::istream& is, LogEntry& entry);

#endif
